Skip to contents

Set all test thresholds to their default values

Usage

set_all_thresholds_to_default(diagnostic_tests = TRUE)

Arguments

diagnostic_tests

Boolean. Whether or not to reset thresholds for diagnostics tests on residuals as well in addition to parametric tests.

Examples

if (FALSE) { # rjd3jars::check_java_version(silent = TRUE)

set_all_thresholds_to_default()
}