Skip to contents

Set thresholds of a given test to their default values

Usage

set_thresholds_to_default(threshold_option_name)

Arguments

threshold_option_name

Boolean. Whether or not to reset thresholds for diagnostics tests on residuals as well in addition to parametric tests.

Examples

if (FALSE) { # rjd3jars::check_java_version(silent = TRUE)

set_thresholds_to_default("t_threshold")
}